Name:          riffle
Version:       1.0.0
Release:       1%{?dist}
Summary:       Annotations and Classes for managing and executing dependent processes
License:       ASL 2.0
# http://github.com/cwensel/riffle
URL:           https://github.com/Cascading/riffle
Source0:       https://github.com/Cascading/riffle/archive/%{version}.tar.gz

BuildRequires: maven-local
BuildRequires: mvn(junit:junit)
BuildRequires: mvn(org.hamcrest:hamcrest-core)

BuildArch:     noarch

%description
Riffle is a lightweight Java library for executing collections of
dependent processes as a single process.

This library provides Java Annotations for tagging classes and
methods supporting required life-cycle stages, and a simple utility
for invoking instances of those classes in dependency order.

It is intended that more robust work-flow tools adopt these Annotations
allowing users and developers across diverse projects to implement and
link to a single life-cycle model without inheriting any incompatible
license restrictions.

%package javadoc
Summary:       Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n %{name}-%{version}
# cleanup
find -name "*.jar" -print -delete
find -name "*.class" -delete

cat > pom.xml << EOF
<?xml version="1.0" encoding="UTF-8"?>
<project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/xsd/maven-4.0.0.xsd">

  <modelVersion>4.0.0</modelVersion>
  <groupId>%{name}</groupId>
  <artifactId>%{name}</artifactId>
  <packaging>jar</packaging>
  <version>%{version}</version>
  <url>%{url}</url>

  <properties>
    <project.build.sourceEncoding>UTF-8</project.build.sourceEncoding>
    <maven.compiler.source>1.7</maven.compiler.source>
    <maven.compiler.target>1.7</maven.compiler.target>
    <timestamp>\${maven.build.timestamp}</timestamp>
    <maven.build.timestamp.format>yyyy</maven.build.timestamp.format>
  </properties>

  <dependencies>
    <dependency>
      <groupId>junit</groupId>
      <artifactId>junit</artifactId>
      <version>4.11</version>
      <scope>test</scope>
    </dependency>
    <dependency>
      <groupId>org.hamcrest</groupId>
      <artifactId>hamcrest-core</artifactId>
      <version>1.3</version>
      <scope>test</scope>
    </dependency>
  </dependencies>

  <build>
    <plugins>
      <plugin>
        <groupId>org.apache.maven.plugins</groupId>
        <artifactId>maven-compiler-plugin</artifactId>
        <version>3.3</version>
        <configuration>
          <source>\${maven.compiler.source}</source>
          <target>\${maven.compiler.target}</target>
        </configuration>
      </plugin>

      <plugin>
        <groupId>org.apache.maven.plugins</groupId>
        <artifactId>maven-javadoc-plugin</artifactId>
        <version>2.10</version>
        <configuration>
          <source>\${maven.compiler.source}</source>
          <sourceEncoding>\${project.build.sourceEncoding}</sourceEncoding>
          <show>public</show>
          <doctitle>%{name} \${project.version} API</doctitle>
          <title>%{name} \${project.version} API</title>
          <bottom><![CDATA[Copyright &#169; 2007-\${maven.build.timestamp} Concurrent, Inc. All Rights Reserved.]]></bottom>
          <additionalparam>-Xdoclint:none</additionalparam>
        </configuration>
      </plugin>

    </plugins>
  </build>
  
</project>
EOF

%mvn_file %{name}:%{name} %{name}

%build

%mvn_build

%install
%mvn_install

%files -f .mfiles
%doc README.txt
%license LICENSE.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt

%changelog
* Sat Nov 07 2015 gil cattaneo <puntogil@libero.it> 1.0.0-1
- update to 1.0.0

* Tue Mar 10 2015 gil cattaneo <puntogil@libero.it> 0.1-0.1.dev
- initial rpm
